# Minicalculator
The Minicalculator is a basic utility calculator the for basic arithmetic operation

## Installation
The minicalculator can be installed from the PYPI library using 

```
pip install minicalculator
```

## Usage
Sample Usage is as follows

```
from mini_calculator.calculator import Calculator

calc = Calculator()

>>> calc.add(5)
5.0
>>> calc.multiply(3)
15.0

```